@@ -18,7 +18,7 @@ class CytraAppBase(GongishApp):
             response.body = response.body.expose()
         GongishApp.format_json(request, response, indent)
 
-    __default_formatter__ = format_json
+    default_formatter = format_json
 
     def __init__(self):
         super().__init__()
