@@ -1,6 +1,6 @@
 from cytra.db.field import Field, relationship, synonym, composite
 
-from cytra.db.inspection_mixin import InspectionMixin
+from cytra.db.inspection_mixin import InspectionMixin, InspectedColumn
 from cytra.db.access_control_mixin import AccessControlMixin
 from cytra.db.transform_mixin import TransformMixin
 from cytra.db.serialize_mixin import SerializeMixin
@@ -21,6 +21,7 @@ __all__ = (
     synonym,
     composite,
     InspectionMixin,
+    InspectedColumn,
     AccessControlMixin,
     TransformMixin,
     SerializeMixin,
