@@ -17,7 +17,7 @@ class DatabaseAppMixin:
 
     def handle_exception(self, exc, start_response):
         if isinstance(exc, SQLAlchemyError):
-            self.__logger__.exception(str(exc))
+            self._log.exception(str(exc))
             if PostgresSQLError.validate_postgres_error(exc):
                 exc = PostgresSQLError(exc)
             else:
