@@ -99,6 +99,10 @@ class FilteringMixin(TransformMixin, AccessControlMixin, InspectionMixin):
             expr = column.is_(None)
         elif value == "!null":
             expr = column.isnot(None)
+        elif value == "!true":
+            expr = column.isnot(True)
+        elif value == "!false":
+            expr = column.isnot(False)
         elif value.startswith("!"):
             expr = column != import_value(column, value[1:])
         elif value.startswith(">="):
